==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/AzureRetentionRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Azure retention rule
 * @property isDefault
 * @property lifecycles
 * @property name
 * @property objectType
 * Expected value is 'AzureRetentionRule'.
 */
public data class AzureRetentionRuleArgs(
    public val isDefault: Output<Boolean>? = null,
    public val lifecycles: Output<List<SourceLifeCycleArgs>>,
    public val name: Output<String>,
    public val objectType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs =
        com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs.builder()
            .isDefault(isDefault?.applyValue({ args0 -> args0 }))
            .lifecycles(
                lifecycles.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .objectType(objectType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureRetentionRuleArgs].
 */
@PulumiTagMarker
public class AzureRetentionRuleArgsBuilder internal constructor() {
    private var isDefault: Output<Boolean>? = null

    private var lifecycles: Output<List<SourceLifeCycleArgs>>? = null

    private var name: Output<String>? = null

    private var objectType: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("mjsrqntqwgyuvqmk")
    public suspend fun isDefault(`value`: Output<Boolean>) {
        this.isDefault = value
    }

    /**
     * @param value
     */
    @JvmName("tnlehkcvhhcsueyd")
    public suspend fun lifecycles(`value`: Output<List<SourceLifeCycleArgs>>) {
        this.lifecycles = value
    }

    @JvmName("kpyjcnavbfoydesm")
    public suspend fun lifecycles(vararg values: Output<SourceLifeCycleArgs>) {
        this.lifecycles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("aoskkbjaqpmanjxd")
    public suspend fun lifecycles(values: List<Output<SourceLifeCycleArgs>>) {
        this.lifecycles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("sddtwjsxcmjdsvsd")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     * Expected value is 'AzureRetentionRule'.
     */
    @JvmName("nshqnnnrjbaogmyi")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value
     */
    @JvmName("vyvlqgdpxdakxvpc")
    public suspend fun isDefault(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDefault = mapped
    }

    /**
     * @param value
     */
    @JvmName("hgwhdejqlukwcyrp")
    public suspend fun lifecycles(`value`: List<SourceLifeCycleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lifecycles = mapped
    }

    /**
     * @param argument
     */
    @JvmName("arjhmjilthfwveey")
    public suspend fun lifecycles(argument: List<suspend SourceLifeCycleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SourceLifeCycleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.lifecycles = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pkijxwydwegxytmm")
    public suspend fun lifecycles(vararg argument: suspend SourceLifeCycleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SourceLifeCycleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.lifecycles = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rpjtqsfljettoxeu")
    public suspend fun lifecycles(argument: suspend SourceLifeCycleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SourceLifeCycleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.lifecycles = mapped
    }

    /**
     * @param values
     */
    @JvmName("kllqrkktjxqyowcm")
    public suspend fun lifecycles(vararg values: SourceLifeCycleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lifecycles = mapped
    }

    /**
     * @param value
     */
    @JvmName("vdikaaymmkujfbih")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     * Expected value is 'AzureRetentionRule'.
     */
    @JvmName("ccwqmoqmtpvcwwos")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): AzureRetentionRuleArgs = AzureRetentionRuleArgs(
        isDefault = isDefault,
        lifecycles = lifecycles ?: throw PulumiNullFieldException("lifecycles"),
        name = name ?: throw PulumiNullFieldException("name"),
        objectType = objectType ?: throw PulumiNullFieldException("objectType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/AzureRetentionRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Azure retention rule
 * @property isDefault
 * @property lifecycles
 * @property name
 * @property objectType
 * Expected value is 'AzureRetentionRule'.
 */
public data class AzureRetentionRuleArgs(
    public val isDefault: Output<Boolean>? = null,
    public val lifecycles: Output<List<SourceLifeCycleArgs>>,
    public val name: Output<String>,
    public val objectType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs =
        com.pulumi.azurenative.dataprotection.inputs.AzureRetentionRuleArgs.builder()
            .isDefault(isDefault?.applyValue({ args0 -> args0 }))
            .lifecycles(
                lifecycles.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .objectType(objectType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureRetentionRuleArgs].
 */
@PulumiTagMarker
public class AzureRetentionRuleArgsBuilder internal constructor() {
    private var isDefault: Output<Boolean>? = null

    private var lifecycles: Output<List<SourceLifeCycleArgs>>? = null

    private var name: Output<String>? = null

    private var objectType: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("lotaxhksaqcqtsyj")
    public suspend fun isDefault(`value`: Output<Boolean>) {
        this.isDefault = value
    }

    /**
     * @param value
     */
    @JvmName("tmtlphppqmyhoxxd")
    public suspend fun lifecycles(`value`: Output<List<SourceLifeCycleArgs>>) {
        this.lifecycles = value
    }

    @JvmName("sbfeyjjjkaahiytr")
    public suspend fun lifecycles(vararg values: Output<SourceLifeCycleArgs>) {
        this.lifecycles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("qtppsvcbcingwadf")
    public suspend fun lifecycles(values: List<Output<SourceLifeCycleArgs>>) {
        this.lifecycles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("gmeayggbepglxfea")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     * Expected value is 'AzureRetentionRule'.
     */
    @JvmName("ervwsckmdwbcgqku")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value
     */
    @JvmName("numbdkoklnxakcvi")
    public suspend fun isDefault(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDefault = mapped
    }

    /**
     * @param value
     */
    @JvmName("vgpggqhbqtwtdsyn")
    public suspend fun lifecycles(`value`: List<SourceLifeCycleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lifecycles = mapped
    }

    /**
     * @param argument
     */
    @JvmName("jkbxrpguhlbxcrwm")
    public suspend fun lifecycles(argument: List<suspend SourceLifeCycleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SourceLifeCycleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.lifecycles = mapped
    }

    /**
     * @param argument
     */
    @JvmName("macpiendrdwgjqou")
    public suspend fun lifecycles(vararg argument: suspend SourceLifeCycleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SourceLifeCycleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.lifecycles = mapped
    }

    /**
     * @param argument
     */
    @JvmName("hvavpqoasxaqlcve")
    public suspend fun lifecycles(argument: suspend SourceLifeCycleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SourceLifeCycleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.lifecycles = mapped
    }

    /**
     * @param values
     */
    @JvmName("jusjxhuskvrqfdne")
    public suspend fun lifecycles(vararg values: SourceLifeCycleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lifecycles = mapped
    }

    /**
     * @param value
     */
    @JvmName("aevbichskostdyfm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     * Expected value is 'AzureRetentionRule'.
     */
    @JvmName("rxcelomndinkntsd")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): AzureRetentionRuleArgs = AzureRetentionRuleArgs(
        isDefault = isDefault,
        lifecycles = lifecycles ?: throw PulumiNullFieldException("lifecycles"),
        name = name ?: throw PulumiNullFieldException("name"),
        objectType = objectType ?: throw PulumiNullFieldException("objectType"),
    )
}
